@@ -86,7 +86,7 @@
 #define ATTICA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef ATTICA_NO_DEPRECATED
-#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef ATTICA_NO_DEPRECATED_WARNINGS
 #  define ATTICA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define ATTICA_DEPRECATED_WARNINGS_SINCE ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -193,7 +193,7 @@
 #define ATTICA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef ATTICA_NO_DEPRECATED
-#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef ATTICA_NO_DEPRECATED_WARNINGS
 #  define ATTICA_DEPRECATED_WARNINGS_SINCE 0
@@ -203,7 +203,7 @@
 #  ifdef ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define ATTICA_DEPRECATED_WARNINGS_SINCE ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
